/*
 * This file is part of Remote Camera.
 *
 * Copyright (C) 2012 Digia Plc
 *
 * Remote Camera is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * Remote Camera is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Remote Camera; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301 USA
 */

import QtQuick 1.1
import com.nokia.meego 1.0
import QtMobility.sensors 1.2
import Gallery 1.0

Page {
    width: parent.width
    height: parent.height


    property int previousWidth: 0

    GalleryModel {
        id: gallerymodel
    }

    Rectangle {
        anchors.fill: parent
        state: gallerypage.state

        Image {
            anchors.fill: parent
            source: "images/background.png"
        }

        ListView {
            id: imagelist
            anchors.fill: parent
            anchors.topMargin: 50
            cacheBuffer: 2000
            model: gallerymodel.thumbs

            delegate: thumbnaildelegate

            states: [
                State {
                    name: "portrait"
                    PropertyChanges {
                        target: imagelist
                        orientation: ListView.Vertical
                    }
                },
                State {
                    name: "landscape"
                    PropertyChanges {
                        target: imagelist
                        orientation: ListView.Horizontal
                    }
                }
            ]
        }

        Image {
            id: gallerytoolbarbackground
            anchors.bottom: parent.bottom
            anchors.left: parent.left
            height: gallerybackbutton.height
            fillMode: Image.Stretch
            source: "images/bottom_toolbar.png"
            visible: true
        }

        Image {
            id: gallerybackbutton
            anchors.bottom: parent.bottom
            anchors.left: parent.left
            source: "images/back_button.png"
            visible: true

            MouseArea {
                anchors.fill: parent

                onClicked: {
                    pageStack.pop();
                }
            }
        }
    }

    Component {
        id: thumbnaildelegate

        Image {
            width: 480
            height: 270
            source: "images/image_frame.png"

            Image {
                id: thumbnailimg
                width: 430
                height: 240
                anchors.centerIn: parent
                asynchronous: true
            }

            GalleryDelegate {
                url: imgurl

                onThumbnailReady: {
                    thumbnailimg.source = "image://thumbnailprovider/" + imgurl;
                }
            }

            Text {
                id: timestamptext
                anchors.top: parent.top
                anchors.right: parent.right
                anchors.topMargin: 20
                anchors.rightMargin: 30
                horizontalAlignment: Text.AlignRight
                font.pixelSize: 20
                color: "#FFFB14"
                text: timestamp
            }

            MouseArea {
                anchors.fill: parent

                onPressAndHold: {
                    gallerymenu.imageurl = imgurl;
                    imagelist.currentIndex = index;
                    gallerymenu.open();
                }

                /*onClicked: {
                    largeimage.source = imgurl;
                    largeimage.visible = true;
                }*/
            }
        }
    }

    /*Image {
        id: largeimage
        anchors.fill: parent
        z: 90
        visible: false
        property bool zoomed: false

        MouseArea {
            anchors.fill: parent

            onClicked: {
                if(largeimage.zoomed)
                {
                    largeimage.zoomed = false;
                }
                else
                {
                    largeimage.width = 854;//1624;
                    largeimage.height = 480;//1224;
                    largeimage.x = mouseX - 427;
                    largeimage.y = mouseY - 240;
                    largeimage.zoomed = true;
                }
            }

            onDoubleClicked: {
                largeimage.visible = false;
                largeimage.zoomed = false;
            }
        }
    }*/

    ContextMenu {
        id: gallerymenu
        visualParent: gallerypage

        property string imageurl: ""

        MenuLayout {
            MenuItem {
                text: "Delete"
                onClicked: {
                    gallerymodel.removePicture(gallerymenu.imageurl);
                    imagelist.decrementCurrentIndex();
                    imagelist.model = gallerymodel.thumbs;
                }
            }
        }
    }

    onStatusChanged: {
        if(gallerypage.status == PageStatus.Activating)
            imagelist.model = gallerymodel.thumbs;
    }

    onWidthChanged: {
        if(previousWidth > 500)
            imagelist.state = "portrait";
        else
            imagelist.state = "landscape";

        previousWidth = gallerypage.width;
    }

    /*function changeOrientation(orientation)
    {
        if(orientation == OrientationReading.TopUp)
            imagelist.state = "portrait"
        else
            imagelist.state = "landscape";
    }*/
}
