/*
 * This file is part of Remote Camera.
 *
 * Copyright (C) 2012 Digia Plc
 *
 * Remote Camera is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * Remote Camera is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Remote Camera; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301 USA
 */

import QtQuick 1.1
import com.nokia.meego 1.0
import QtMultimediaKit 1.1

Page {
    width: parent.width
    height: parent.height

    Item {
        id: mainpagestatus

        property bool p_started: false

        function countdownStop () {
            countdowntext.visible = false;
            countdowntimer.stop();
        }

        function countdownStart () {
            countdowntext.text = settinghandler.starttimer;
            countdowntimer.secondsRemaining = settinghandler.starttimer;
            countdowntext.visible = true;
            countdowntimer.start();
        }

        states: [
            State {
                name: "stopped"
                PropertyChanges {target: thresholdsettings; visible: true}
                PropertyChanges {target: stopbutton; visible: false}
                PropertyChanges {target: basicbuttons; visible: true}
                PropertyChanges {target: mainpagestatus; p_started: false}
            },
            State {
                name: "countingdown";
                PropertyChanges {target: thresholdsettings; visible: false}
                PropertyChanges {target: stopbutton; visible: true}
                PropertyChanges {target: basicbuttons; visible: false}
            },
            State {
                name: "started";
                PropertyChanges {target: thresholdsettings; visible: true}
                PropertyChanges {target: stopbutton; visible: true}
                PropertyChanges {target: basicbuttons; visible: false}
                PropertyChanges {target: mainpagestatus; p_started: true}
            },
            State {
                name: "standby"
                PropertyChanges {target: thresholdsettings; visible: false}
                PropertyChanges {target: stopbutton; visible: false}
                PropertyChanges {target: basicbuttons; visible: false}
                PropertyChanges {target: mainpagestatus; p_started: mainpagestatus.p_started}
                PropertyChanges {target: img; source: "images/standby.png"}
            }
        ]
        transitions: [
            Transition {
                from: "countingdown"; to: "*"
                ScriptAction { script: mainpagestatus.countdownStop() }
            },
            Transition {
                from: "*"; to: "countingdown"
                ScriptAction { script: mainpagestatus.countdownStart() }
            }
        ]
    }

    Image {
        id: img
        anchors.top: parent.top
        anchors.left: parent.left
        width: 854
        height: 480

        PinchArea {
            id: zoompinch
            anchors.fill: parent

            property int old_pinchval: 1;
            property double old_zoom: 1.0

            function pinchvalue(pinch) {
                return Math.abs(pinch.point2.x - pinch.point1.x) + Math.abs(pinch.point2.y - pinch.point1.y)
            }

            onPinchStarted: {
                zoompinch.old_pinchval = Math.max (1, pinchvalue(pinch));
                zoompinch.old_zoom = gsthandler.getZoom();
            }
            onPinchUpdated: {
                var zoom = (pinchvalue(pinch) * zoompinch.old_zoom) / zoompinch.old_pinchval;
                gsthandler.setZoom(zoom);
            }
        }
    }

    Image {
      id: stopbutton
      anchors.right: parent.right
      anchors.rightMargin: 10
      anchors.verticalCenter: parent.verticalCenter
      source: "images/stop_button.png"
      visible: false


      MouseArea {
          anchors.fill: parent

          onClicked: {
              mainpagestatus.state = "stopped"
          }
      }
    }

    Item {
        id: thresholdsettings
        width: parent.width
        height: parent.height
        visible: true

        Item {
            id: thresholdrect
            width: parent.width
            anchors.bottom: parent.bottom

            Image {
                anchors.bottom: parent.bottom
                source: "images/bottom_toolbar.png"

                MouseArea {
                    anchors.fill: parent
                    drag.target: thresholdindicator
                    drag.axis: Drag.XAxis
                    drag.minimumX: -12
                    drag.maximumX: 762

                    function updateThreshold ()
                    {
                        if (containsMouse) {
                            var newThreshold = ((thresholdindicator.x + 12)) / progressbarbackground.width * 99
                            settinghandler.setTriggerthreshold(newThreshold > 0 ? newThreshold : 0)
                        }
                    }
                    onPressed: {
                        updateThreshold ()
                    }
                    onPositionChanged: {
                        updateThreshold ()
                    }
                    onReleased: {
                        settinghandler.saveSettings();
                    }
                }

                Item {
                    //dark area of bottom_toolbar.png
                    anchors.bottom: parent.bottom
                    width: parent.width
                    height: 64

                    Image {
                        id: progressbarbackground
                        anchors.centerIn: parent
                        source: "images/wide_progressbar_bg.png"

                        Image {
                            id: motionindicator
                            width: 20
                            anchors.verticalCenter: parent.verticalCenter
                            anchors.left: parent.left
                            source: "images/wide_progressbar.png"

                            Behavior on width {
                                SmoothedAnimation {
                                    id: indicatoranimation
                                    velocity: 100
                                }
                            }
                        }

                        Image {
                            id: thresholdindicator
                            anchors.verticalCenter: parent.verticalCenter
                            x: settinghandler.triggerthreshold / 100.0 * progressbarbackground.width - 12
                            source: "images/seek.png"

                            property int value: 0

                            /*Image {
                                id: litindicator
                                anchors.centerIn: parent
                                source: "images/seek_lit.png"
                                opacity: 0

                                PropertyAnimation {
                                    id: litanimation
                                    target: litindicator
                                    property: "opacity"
                                    to: 0
                                    duration: 1000
                                }
                            }*/
                        }
                    }
                }
            }
        }
    }

    Item {
        id: basicbuttons
        anchors.fill: parent

        Image {
            source: "images/settings_button.png"
            anchors.top: parent.top
            anchors.right: parent.right
            anchors.margins: 10

            MouseArea {
                anchors.fill: parent

                onClicked: {
                    pageStack.push(setpage);
                }
            }
        }

        Image {
            source: "images/start_button.png"
            anchors.right: parent.right
            anchors.rightMargin: 10
            anchors.verticalCenter: parent.verticalCenter

            MouseArea {
                anchors.fill: parent

                onClicked: {
                    if (settinghandler.starttimer > 0) {
                        mainpagestatus.state = "countingdown";
                    } else {
                        mainpagestatus.state = "started";
                        cooldowntimer.start();
                    }
                }
            }
        }

        Image {
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.margins: 10
            source: "images/gallery_button.png"

            MouseArea {
                anchors.fill: parent

                onClicked: {
                    pageStack.push(gallerypage);
                }
            }
        }
    }

    Text {
        id: countdowntext
        text: ""
        horizontalAlignment: Text.horizontalAlignment
        anchors.centerIn: parent
        color: "#FFFFFF"
        font.pixelSize: 150
        opacity: 0.4
    }

    Timer {
        id: countdowntimer
        interval: 1000
        repeat: true
        running: false

        property int secondsRemaining: 0

        onTriggered: {
            secondsRemaining--;
            countdowntext.text = secondsRemaining;
            if (secondsRemaining < 1) {
                mainpagestatus.state = "started";
            }
        }
    }

    Timer {
        id: cooldowntimer
        interval: settinghandler.cooldown * 1000
        repeat: false
        running: false
    }

    Rectangle {
        id: saverrect
        width: appWindow.width
        height: appWindow.height
        color: "#000000"
        visible: false
        z: 90

        Text {
            id: savertext
            x: Math.floor(Math.random() * 700)
            y: Math.floor(Math.random() * 400)
            color: "#888888"
            font.pixelSize: 32
            text: "Tap to open"
        }

        MouseArea {
            anchors.fill: parent

            onClicked: {
                gsthandler.initializeScreensaver(settinghandler.pwrsave);
                gsthandler.disablePowerSave();
                saverrect.visible = false;
            }
        }
    }

    SoundEffect {
        id: capturesound
        source: "audio/capture.wav"
    }

    Connections {
        id: conn
        target: gsthandler

        onImageUpdated: {
            img.source = "image://imageprovider/feedimage_" + Math.random(123);
        }

        onMotionVectorReceived: {
            // Upscale the received motion in order to make threshold adjustment
            // using the slider a bit easier with small motion values.
            var scaled_motion = motionval * 3;
            if (scaled_motion * 100 > thresholdindicator.value) {
                thresholdindicator.source = "images/seek_lit.png";
                //litindicator.opacity = 1;
                timedevents.startIndicatorTimer();
                if (mainpagestatus.p_started && cooldowntimer.running == false) {
                        // Take picture
                        gsthandler.capture();
                        capturesound.play();
                        cooldowntimer.restart();
                }
            }

            if (thresholdsettings.visible) {
                var newwidth = scaled_motion * 774;
                if(newwidth > motionindicator.width)
                    indicatoranimation.velocity = -1;
                else
                    indicatoranimation.velocity = 100;

                if(newwidth > 774)
                    newwidth = 774;

                motionindicator.width = newwidth;
            }
        }

        onGoneStandby: {
            mainpagestatus.state = "standby";
        }

        onScreensaverActivated: {
            saverrect.visible = true;
            timedevents.startCoordinateTimer();
        }

        onImageDone: {
            messagehandler.sendEmail(filename);
        }

        onFocusingDone: {
            // Cool down after focusing has finished in order to
            // avoid triggering immediately
            cooldowntimer.restart();
        }

        onResReceived: {
            if (mainpagestatus.p_started == true) {
                mainpagestatus.state = "started";
            } else {
                mainpagestatus.state = "stopped";
            }
        }
        /*
        onResDenied: {
            debug.text += "denied";
        }

        onResAvailable: {
            debug.text += "available";
        }

        onResLost: {
            debug.text += "lost";
        }

        onResReleased: {
            debug.text += "released";
        }*/
    }

    Connections {
        target: settinghandler

        onPwrsaveChanged: {
            gsthandler.initializeScreensaver(settinghandler.pwrsave);
        }

        onCooldownChanged: {
            cooldowntimer.interval = settinghandler.cooldown * 1000;
        }

        onTriggerthresholdChanged: {
            thresholdindicator.value = settinghandler.triggerthreshold;
            thresholdindicator.x = settinghandler.triggerthreshold / 100.0 * progressbarbackground.width - 12
            //triggerindicator.width = triggerindicator.height = settinghandler.triggerthreshold / 50 * 340 + 60;
        }

        onVblocksChanged: {
            // using the same value for a reason
            gsthandler.setVblocks(settinghandler.vblocks);
            gsthandler.setHblocks(settinghandler.vblocks);
        }
    }

    Connections {
        target: timedevents

        onSaverCoords: {
            savertext.x = x;
            savertext.y = y;
            timedevents.startCoordinateTimer();
        }

        onWakeup: {
            gsthandler.wakeFromIdle();
        }

        onIndicator: {
            //litanimation.running = true;
            thresholdindicator.source = "images/seek.png";
        }
    }

    onStatusChanged: {
        if (mainPage.status == PageStatus.Inactive) {
            gsthandler.goIdle();
        }
        if (mainPage.status == PageStatus.Activating) {
            img.source = "images/splash.png"
            timedevents.startWakeupTimer();
        }
    }

    Component.onCompleted: {
        gsthandler.initializeScreensaver(settinghandler.pwrsave);
        thresholdindicator.value = settinghandler.triggerthreshold;
        // using the same value for a reason
        gsthandler.setVblocks(settinghandler.vblocks);
        gsthandler.setHblocks(settinghandler.vblocks);
        // setting startup email values for message handler
        messagehandler.setAddress(settinghandler.email);
        messagehandler.setMessageSending(settinghandler.emailEnabled);
    }
}
