/*
 * This file is part of Remote Camera.
 *
 * Copyright (C) 2012 Digia Plc
 *
 * Remote Camera is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * Remote Camera is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Remote Camera; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301 USA
 */

import QtQuick 1.1
import com.nokia.meego 1.0

Page {
    width: parent.width
    height: parent.height

    Image {
        anchors.fill: parent
        width: 854
        source: "images/background.png"
    }

    Image {
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right
        source: "images/toolbar_top.png"
        z: 60

        Text {
            anchors.top: parent.top
            anchors.topMargin: 12
            anchors.left: parent.left
            anchors.leftMargin: 30
            color: "#BBBBBB"
            font.pixelSize: 38
            font.family: "Nokia Pure Text"
            font.weight: Font.Light
            text: "Settings"
        }
    }

    Flickable {
        id: flickable
        width: parent.width - 60
        height: parent.height - settingtoolbar.height
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.leftMargin: 30
        anchors.rightMargin: 30
        contentHeight: slidercolumn.height + 25
        flickableDirection: Flickable.VerticalFlick

        Column {
            id: slidercolumn
            width: parent.width
            spacing: 5

            Item {
                width: parent.width
                height: 80
            }

            Column {
                spacing: 5
                width: parent.width

                Text {
                    font.pixelSize: 26
                    color: "#FFFFFF"
                    text: "Power save timeout (s)"
                }

                SettingsSlider {
                    id: pwrsaveslide
                    width: parent.width
                    maximumValue: 300
                    minimumValue: 10
                    value: settinghandler.pwrsave
                    stepSize: 10

                    onValueSet: {
                        settinghandler.setPwrsave(pwrsaveslide.value);
                        settinghandler.saveSettings();
                    }
                }
            }

            Column {
                spacing: 5
                width: parent.width

                Text {
                    font.pixelSize: 26
                    color: "#FFFFFF"
                    text: "Start timer (s)"
                }

                SettingsSlider {
                    id: starttimeslide
                    width: parent.width
                    maximumValue: 300
                    minimumValue: 0
                    value: settinghandler.starttimer
                    stepSize: 10

                    onValueSet: {
                        settinghandler.setStarttimer(starttimeslide.value);
                        settinghandler.saveSettings();
                    }
                }
            }

            Column {
                spacing: 5
                width: parent.width

                Text {
                    font.pixelSize: 26
                    color: "#FFFFFF"
                    text: "Minimum time between captures (s)"
                }

                SettingsSlider {
                    id: cooldownslide
                    width: parent.width
                    maximumValue: 60
                    minimumValue: 1
                    value: settinghandler.cooldown
                    stepSize: 1

                    onValueSet: {
                        settinghandler.setCooldown(cooldownslide.value);
                        settinghandler.saveSettings();
                    }
                }
            }

            Column {
                spacing: 5
                width: parent.width

                Text {
                    font.pixelSize: 26
                    color: "#FFFFFF"
                    text: "Image capture threshold"
                }

                SettingsSlider {
                    id: triggerslide
                    width: parent.width
                    maximumValue: 0.99
                    minimumValue: 0
                    value: settinghandler.triggerthreshold / 100.0
                    stepSize: 0.01

                    onValueSet: {
                        settinghandler.setTriggerthreshold(triggerslide.value * 100.0);
                        settinghandler.saveSettings();
                    }
                }
            }

            Column {
                spacing: 5
                width: parent.width

                Text {
                    font.pixelSize: 26
                    color: "#FFFFFF"
                    text: "Motion detection blocks"
                }

                SettingsSlider {
                    id: vblockslide
                    width: parent.width
                    maximumValue: 16
                    minimumValue: 1
                    value: settinghandler.vblocks
                    stepSize: 1

                    onValueSet: {
                        settinghandler.setVblocks(vblockslide.value);
                        settinghandler.setHblocks(vblockslide.value);
                        settinghandler.saveSettings();
                    }
                }
            }

            /*Column {
                spacing: 5
                width: parent.width

                Text {
                    font.pixelSize: 26
                    color: "#FFFFFF"
                    text: "Horizontal sensitivity"
                }

                SettingsSlider {
                    id: hblockslide
                    width: parent.width
                    maximumValue: 16
                    minimumValue: 1
                    value: 12
                    stepSize: 1

                    onValueSet: {
                        settinghandler.setHblocks(hblockslide.value);
                        gsthandler.setHblocks(hblockslide.value);
                    }
                }
            }*/

            Column {
                spacing: 12
                width: parent.width

                //Row {

                    Text {
                        font.pixelSize: 26
                        color: "#FFFFFF"
                        text: "Send images using e-mail"
                    }

                    Switch {
                        id: messageSwitch

                        onCheckedChanged:
                        {
                            if (messageSwitch.checked == true)
                            {
                                messageSettingsColumn.visible = true
                                messagehandler.setMessageSending(true)
                                settinghandler.enableEmail(true)
                                settinghandler.saveSettings()
                                address.focus = true;
                            }
                            else
                            {
                                messageSettingsColumn.visible = false
                                messagehandler.setMessageSending(false)
                                settinghandler.enableEmail(false)
                                settinghandler.saveSettings()
                            }
                        }
                    }

                //}

                Column {
                    id: messageSettingsColumn
                    visible: false
                    anchors.left: parent.left
                    width: parent.width
                    spacing: 12

                    /* MMS messaging option removed
                    ButtonRow {

                        RadioButton {
                            id: emailRadioButton
                            text: "Email"
                            checked: true

                            onCheckedChanged:
                            {
                                if (emailRadioButton.checked)
                                {
                                    addressText.text = "Email address:"
                                    messagehandler.setMessageType(4, 3)
                                }
                            }

                        }

                        RadioButton {
                            id: mmsRadioButton
                            text: "MMS"

                            onCheckedChanged:
                            {
                                if (mmsRadioButton.checked)
                                {
                                    addressText.text = "Phone number:"
                                    messagehandler.setMessageType(1, 2)
                                }
                            }

                        }

                    } */

                    Text {
                        id: addressText
                        font.pixelSize: 26
                        color: "#FFFFFF"
                        text: "E-mail address"
                    }

                    TextField {
                        id: address
                        width: parent.width
                        text: settinghandler.email
                        inputMethodHints: Qt.ImhNoPredictiveText | Qt.ImhEmailCharactersOnly

                        onActiveFocusChanged:
                        {
                            if (focus == false)
                            {
                                messagehandler.setAddress(address.text)
                                settinghandler.setEmail(address.text)
                                settinghandler.saveSettings()
                            }
                        }

                        Keys.onReturnPressed:
                        {
                            platformCloseSoftwareInputPanel()
                            addressText.focus = true
                        }

                    }



                }

                    /*TODO: For testing
                    Button {
                        text: "Check messages"

                        onClicked: {
                            messagehandler.checkNewMessages();
                        }
                    }

                    TextField {
                        id: filetosend
                    }

                    //TODO: For testing
                    Button {
                        text: "Send message"

                        onClicked: {
                            messagehandler.sendEmail(filetosend.text);
                        }
                    }*/

            }
        }
    }

    /*ScrollDecorator {
        id: scrolldecorator
        flickableItem: flickable
    }*/

    ToolBar {
        id: settingtoolbar
        anchors.bottom: parent.bottom
        tools: ToolBarLayout {

            ToolIcon {
                anchors.left: parent.left
                //anchors.margins: 25
                iconId: "toolbar-back";

                onClicked: {
                    pageStack.pop();
                }
            }

            ToolIcon {
                iconId: "toolbar-view-menu";

                onClicked: {
                    inforect.visible = true;
                }
            }
        }

        /*style: ToolBarStyle {
            background: "images/bottom_toolbar.png"
        }*/
    }

    Image {
        id: inforect
        anchors.centerIn: parent
        visible: false
        source: "images/modal_window.png"
        rotation: (setpage.width > 500) ? 0 : 90
        z: 90

        Text {
            id: apptext
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.margins: 30
            color: "#BBBBBB"
            font.pixelSize: 34
            text: "Remote Camera 1.3"
        }

        Text {
            id: devtext
            anchors.top: apptext.bottom
            anchors.left: parent.left
            anchors.margins: 30
            color: "#CCCCCC"
            font.pixelSize: 14
            text: "Copyright Digia Plc, 2012. Licensed under GNU LGPL version 2.1."
        }

        Text {
            anchors.top: devtext.bottom
            anchors.left: parent.left
            anchors.margins: 30
            color: "#CCCCCC"
            font.pixelSize: 18
            text:
            "Remote Camera takes pictures automatically based on detected motion, and delivers\n" +
            "pictures by e-mail after they are taken. Point your camera, adjust capture threshold and start.\n" +
            "\n" +
            "Features:\n" +
            " * Detected motion in front of camera triggers image capture\n" +
            " * View a list of taken pictures in gallery page\n" +
            " * Receive taken pictures via e-mail as they are taken\n" +
            " * Power save mode for extended use time\n"

        }

        Image {
            anchors.left: parent.left
            anchors.bottom: parent.bottom
            anchors.margins: 35
            source: "images/logo.png"
        }

        MouseArea {
            anchors.top: parent.top
            anchors.right: parent.right
            width: 100
            height: 100

            onClicked: {
                inforect.visible = false;
            }
        }
    }

    Component.onCompleted: {
        messageSwitch.checked = settinghandler.emailEnabled;
    }
}
