/*
 * This file is part of Remote Camera.
 *
 * Copyright (C) 2012 Digia Plc
 *
 * Remote Camera is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * Remote Camera is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Remote Camera; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301 USA
 */

import QtQuick 1.1

Item {
    width: 417
    height: 55
    property real value: 0
    property real minimumValue: 0
    property real maximumValue: 1
    property real stepSize: 1
    property real stepInPixels: 1
    property int numSteps: 1
    property int previousWidth: 0

    signal valueSet(real value)

    Image {
        id: progressbarback
        width: parent.width - 45
        anchors.centerIn: parent
        source: "images/small_progessbar_bg.png"

        Image {
            id: progressbar
            width: parent.width
            anchors.left: parent.left
            source: "images/small_progessbar.png"
        }

        Rectangle {
            id: valueindicatorrect
            width: 45
            height: 30
            color: "#222222"
            radius: 10
            anchors.horizontalCenter: handle.horizontalCenter
            anchors.verticalCenter: handle.verticalCenter
            anchors.verticalCenterOffset: -50
            visible: false

            Text {
                id: valueindicatortext
                font.pixelSize: 24
                anchors.centerIn: parent
                color: "#DDDDDD"
                text: value
            }
        }

        Image {
            id: handle
            anchors.verticalCenter: parent.verticalCenter
            x: -25
            source: "images/handle.png"

            MouseArea {
                anchors.fill: parent
                drag.target: handle
                drag.axis: Drag.XAxis
                drag.minimumX: -25
                drag.maximumX: progressbarback.width - 25

                onPressed: {
                    valueindicatorrect.visible = true;
                }

                onPositionChanged: {
                    if(drag.active)
                    {
                        value = minimumValue + Math.round((handle.x + 25) / stepInPixels) * stepSize;
                        progressbar.width = handle.x + 25;
                        valueindicatortext.text = value;
                        valueChanged(value);
                    }
                }

                onReleased: {
                    valueindicatorrect.visible = false;
                    valueSet(value);
                }
            }
        }
    }

    onValueChanged: {
        setHandlePosition();
    }

    onWidthChanged: {
        if(previousWidth > 0)
        {
            stepInPixels = previousWidth / numSteps;
            setHandlePosition();
        }
        previousWidth = progressbarback.width;
    }

    Component.onCompleted: {
        numSteps = Math.ceil((maximumValue - minimumValue) / stepSize);
        stepInPixels = progressbarback.width / numSteps;
        setHandlePosition();
    }

    function setHandlePosition()
    {
        handle.x = Math.round((value - minimumValue) / (maximumValue - minimumValue) * numSteps) * stepInPixels - 25;
        progressbar.width = handle.x + 25;
    }
}
